@@ -177,6 +177,10 @@ pub enum Expr {
         expr: Box<Expr>,
         reverse: bool,
     },
+    Take {
+        expr: Box<Expr>,
+        idx: Box<Expr>,
+    },
     SortBy {
         expr: Box<Expr>,
         by: Box<Expr>,
@@ -277,6 +281,9 @@ impl fmt::Debug for Expr {
             Filter { input, by } => {
                 write!(f, "FILTER {:?} BY {:?}", input, by)
             }
+            Take { expr, idx } => {
+                write!(f, "TAKE {:?} AT {:?}", expr, idx)
+            }
             Agg(agg) => {
                 use AggExpr::*;
                 match agg {
@@ -549,6 +556,25 @@ impl Expr {
         self.slice(-(len as i64), len)
     }
 
+    /// Get unique values of this expression.
+    pub fn unique(self) -> Self {
+        if has_expr(&self, |e| matches!(e, Expr::Wildcard)) {
+            panic!("wildcard not supperted in unique expr");
+        }
+        self.map(|s: Series| s.unique(), None)
+    }
+
+    /// Get the first index of unique values of this expression.
+    pub fn arg_unique(self) -> Self {
+        if has_expr(&self, |e| matches!(e, Expr::Wildcard)) {
+            panic!("wildcard not supported in unique expr");
+        }
+        self.map(
+            |s: Series| s.arg_unique().map(|ca| ca.into_series()),
+            Some(DataType::UInt32),
+        )
+    }
+
     /// Cast expression to another data type.
     pub fn cast(self, data_type: DataType) -> Self {
         Expr::Cast {
@@ -557,6 +583,14 @@ impl Expr {
         }
     }
 
+    /// Take the values by idx.
+    pub fn take(self, idx: Expr) -> Self {
+        Expr::Take {
+            expr: Box::new(self),
+            idx: Box::new(idx),
+        }
+    }
+
     /// Sort in increasing order. See [the eager implementation](polars_core::series::SeriesTrait::sort).
     ///
     /// Can be used in `default` and `aggregation` context.
