@@ -3,7 +3,6 @@ use std::collections::HashMap;
 use std::sync::Arc;
 
 use ahash::RandomState;
-use itertools::Itertools;
 
 use polars_core::frame::hash_join::JoinType;
 use polars_core::prelude::*;
@@ -497,14 +496,18 @@ impl LazyFrame {
         {
             // only check by names because we may supercast types.
             assert_eq!(
-                prev_schema.fields().iter().map(|f| f.name()).collect_vec(),
+                prev_schema
+                    .fields()
+                    .iter()
+                    .map(|f| f.name())
+                    .collect::<Vec<_>>(),
                 lp_arena
                     .get(lp_top)
                     .schema(lp_arena)
                     .fields()
                     .iter()
                     .map(|f| f.name())
-                    .collect_vec()
+                    .collect::<Vec<_>>()
             );
         };
 
@@ -1846,7 +1849,7 @@ mod test {
 
         assert_eq!(
             out.column("a_mean").unwrap().f64().unwrap().get(0),
-            Some(0.5)
+            Some(1.0)
         );
     }
 
