@@ -684,6 +684,10 @@ fn replace_wildcard_with_column(expr: Expr, column_name: Arc<String>) -> Expr {
         Expr::Explode(expr) => {
             Expr::Explode(Box::new(replace_wildcard_with_column(*expr, column_name)))
         }
+        Expr::Take { expr, idx } => Expr::Take {
+            expr: Box::new(replace_wildcard_with_column(*expr, column_name)),
+            idx,
+        },
         Expr::Ternary {
             predicate,
             truthy,
