@@ -396,20 +396,17 @@ impl DefaultPlanner {
                 order_by: _,
             } => {
                 // TODO! Order by
-                let group_column = aexpr_to_root_names(partition_by, expr_arena)
-                    .pop()
-                    .expect("need a partition_by column for a window function");
-                let out_name;
+                let group_column =
+                    self.create_physical_expr(partition_by, Context::Default, expr_arena)?;
+                let mut out_name = None;
                 let apply_column = aexpr_to_root_names(function, expr_arena)
                     .pop()
                     .expect("need a root column for a window function");
 
                 if let Alias(expr, name) = expr_arena.get(function) {
                     function = *expr;
-                    out_name = name.clone();
-                } else {
-                    out_name = group_column.clone();
-                }
+                    out_name = Some(name.clone());
+                };
                 let function = node_to_exp(function, expr_arena);
 
                 Ok(Arc::new(WindowExpr {
@@ -426,7 +423,7 @@ impl DefaultPlanner {
             BinaryExpr { left, op, right } => {
                 let lhs = self.create_physical_expr(left, ctxt, expr_arena)?;
                 let rhs = self.create_physical_expr(right, ctxt, expr_arena)?;
-                Ok(Arc::new(phys_expr::BinaryExpr::new(
+                Ok(Arc::new(phys_expr::binary::BinaryExpr::new(
                     lhs,
                     op,
                     rhs,
@@ -445,6 +442,11 @@ impl DefaultPlanner {
                     node_to_exp(expression, expr_arena),
                 )))
             }
+            Take { expr, idx } => {
+                let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
+                let phys_idx = self.create_physical_expr(idx, ctxt, expr_arena)?;
+                Ok(Arc::new(TakeExpr::new(phys_expr, phys_idx)))
+            }
             SortBy { expr, by, reverse } => {
                 let phys_expr = self.create_physical_expr(expr, ctxt, expr_arena)?;
                 let phys_by = self.create_physical_expr(by, ctxt, expr_arena)?;
